@@ -10,7 +10,7 @@ data("pandata_simulated")
 # plot(pandata_simulated$gdp[pandata_simulated$country==3], type="l", main="Country 3 (No Break)")
 # plot(pandata_simulated$gdp[pandata_simulated$country==4], type="l", main="Country 4 (No Break)")
 
-pandata_simulated <- pandata_simulated[pandata_simulated$year>1979,]
+pandata_simulated <- pandata_simulated[pandata_simulated$year<1951,]
 
 # Normal testing
 
@@ -23,12 +23,19 @@ pandata_simulated <- pandata_simulated[pandata_simulated$year>1979,]
 # Unit testing
 test_that("Initial Tests Isatpanel on simulated data",{
 
-  expect_message(isatpanel(data = pandata_simulated,formula = gdp~temp, index = c("country","year"),fesis = TRUE))
+  expect_message(isatpanel(data = pandata_simulated,formula = gdp~temp, index = c("country","year"), fesis = TRUE, effect = "twoways",
+                           print.searchinfo = TRUE))
 
   #newmethod <- isatpanel(data = pandata_simulated,formula = gdp~temp + I(temp^2), index = c("country","year"),fesis=TRUE)
 
   expect_message(isatpanel(data = pandata_simulated,formula = gdp~temp + I(temp^2),
-                           index = c("country","year"),fesis=TRUE, ar = 1))
+                           index = c("country","year"),fesis=TRUE, ar = 1, effect = "twoways"))
+
+
+  expect_warning(isatpanel(data = pandata_simulated,formula = gdp~temp + I(temp^2),
+                           index = c("country","year"),fesis=TRUE, ar = 1),
+                 regexp = "New default for effect in 'isatpanel': Used to be 'individual', now 'twoways'.")
+
 
 })
 
@@ -36,13 +43,12 @@ test_that("Initial Tests Isatpanel on simulated data",{
 
 test_that("Isatpanel Test that missing values are removed",{
   data_w_missing <- pandata_simulated
-  data_w_missing <- data_w_missing[data_w_missing$year>1979,]
-  data_w_missing$temp <- ifelse(data_w_missing$country == 2, NA, data_w_missing$temp)
+  data_w_missing$temp <- ifelse(data_w_missing$country == 2 & data_w_missing$year>1939, NA, data_w_missing$temp)
 
   expect_silent(a <- isatpanel(data = data_w_missing,formula = gdp~temp,
                                index = c("country","year"),fesis = TRUE, print.searchinfo = FALSE))
   expect_output(print(a))
-  expect_true(a$isatpanel.result$n==63) # 63 because 3 * 21
+  expect_true(a$isatpanel.result$n==189)
 })
 
 
@@ -50,8 +56,34 @@ test_that("Isatpanel Test that missing values are removed",{
 test_that("Test the cfesis and csis arguments",{
 
   expect_silent(isatpanel(data = pandata_simulated,formula = gdp~temp + I(temp^2), index = c("country","year"),fesis=TRUE, cfesis = TRUE, ar = 1, print.searchinfo = FALSE))
-  expect_silent(newmethod_cfesis_sub <- isatpanel(data = pandata_simulated,formula = gdp~temp + I(temp^2), index = c("country","year"),fesis=TRUE, cfesis = TRUE,cfesis_id = c("2","3"), ar = 1, print.searchinfo = FALSE))
+  expect_silent(newmethod_cfesis_sub <- isatpanel(data = pandata_simulated,formula = gdp~temp + I(temp^2),
+                                                  index = c("country","year"),fesis=TRUE, cfesis = TRUE,cfesis_id = c("2","3"), ar = 1,
+                                                  print.searchinfo = FALSE))
 
+
+  expect_error(isatpanel(data = pandata_simulated,formula = gdp~temp + I(temp^2), index = c("country","year"),
+                         fesis=TRUE, cfesis = TRUE, ar = 1, print.searchinfo = FALSE, fesis_id = "Test"),
+               regexp = "Some or all id names in 'fesis_id' not found in the data.")
+
+  expect_error(isatpanel(data = pandata_simulated,formula = gdp~temp + I(temp^2), index = c("country","year"),
+                         fesis=TRUE, cfesis = TRUE, ar = 1, print.searchinfo = FALSE, cfesis_id = "Test"),
+               regexp = "Some or all id names in 'cfesis_id' not found in the data.")
+
+  expect_error(isatpanel(data = pandata_simulated,formula = gdp~temp + I(temp^2), index = c("country","year"),
+                         fesis=TRUE, cfesis = TRUE, ar = 1, print.searchinfo = FALSE, cfesis_id = "Test", fesis_id = "Test"),
+               regexp = "Some or all id names in 'cfesis_id' not found in the data.")
+
+  expect_error(isatpanel(data = pandata_simulated,formula = gdp~temp + I(temp^2), index = c("country","year"),
+                         fesis=TRUE, cfesis = TRUE, ar = 1, print.searchinfo = FALSE, cfesis_var = "Test"),
+               regexp = "Some or all variable names in 'cfesis_var' not found in the data.")
+
+  expect_error(isatpanel(data = pandata_simulated,formula = gdp~temp + I(temp^2), index = c("country","year"),
+                         fesis=TRUE, cfesis = TRUE, ar = 1, print.searchinfo = FALSE, csis_var = "Test"),
+               regexp = "You cannot specify csis_var when csis = FALSE.")
+
+  expect_error(isatpanel(data = pandata_simulated,formula = gdp~temp + I(temp^2), index = c("country","year"),
+                         fesis=TRUE, cfesis = TRUE, csis = TRUE, ar = 1, print.searchinfo = FALSE, csis_var = "Test"),
+               regexp = "Some or all variable names in 'csis_var' not found in the data.")
 })
 
 
@@ -62,8 +94,10 @@ test_that("Test the cfesis and csis arguments",{
 
 test_that("Standard Error Options using fixest",{
   skip_on_cran()
-  expect_silent(result <- isatpanel(data = pandata_simulated,formula = gdp~temp + I(temp^2), index = c("country","year"),fesis=TRUE, ar = 1, print.searchinfo=FALSE,engine = "fixest"))
-  expect_silent(result <- isatpanel(data = pandata_simulated,formula = gdp~temp + I(temp^2), index = c("country","year"),fesis=TRUE, ar = 1, print.searchinfo=FALSE,engine = "fixest", cluster = "individual"))
+  expect_silent(result <- isatpanel(data = pandata_simulated,formula = gdp~temp + I(temp^2), index = c("country","year"),fesis=TRUE, ar = 1,
+                                    print.searchinfo=FALSE,engine = "fixest"))
+  expect_silent(result <- isatpanel(data = pandata_simulated,formula = gdp~temp + I(temp^2), index = c("country","year"),fesis=TRUE, ar = 1,
+                                    print.searchinfo=FALSE,engine = "fixest", cluster = "individual"))
 })
 
 
@@ -165,8 +199,7 @@ test_that("Simple Default Test with AR1",{
 
 test_that("Test that estimates of IIS are equal across methods and including perfectly linear terms", {
   skip_on_cran()
-  pandata_simulated$int_rate <- rep(rnorm(21),4)
-  pandata_simulated <- pandata_simulated[pandata_simulated$year>1979,]
+  pandata_simulated$int_rate <- rep(rnorm(50),4)
 
   aa <- isatpanel(data = pandata_simulated,formula = gdp~temp,
                   index = c("country","year"),fesis = FALSE, iis = TRUE, effect = c("twoways"), print.searchinfo = FALSE)
@@ -195,7 +228,6 @@ test_that("Test that estimates of IIS are equal across methods and including per
 
 test_that("Test that estimates of FESIS are equal across methods", {
   skip_on_cran()
-  data("pandata_simulated")
 
   aa <- isatpanel(data = pandata_simulated,formula = gdp~temp,
                   index = c("country","year"), fesis = TRUE, effect = c("twoways"), print.searchinfo = FALSE)
@@ -216,20 +248,6 @@ test_that("Test that estimates of FESIS are equal across methods", {
 })
 
 
-test_that("Test that estimates of FESIS are equal across methods", {
-  #skip_on_ci()
-  skip_on_cran()
-  data("pandata_simulated")
-  pandata_simulated <- pandata_simulated[pandata_simulated$year>1979,]
-  aa <- isatpanel(data = pandata_simulated,formula = gdp~temp,
-                  index = c("country","year"), fesis = TRUE, effect = c("twoways"), print.searchinfo = FALSE)
-
-  bb <- isatpanel(data = pandata_simulated,formula = gdp~temp,
-                  index = c("country","year"), fesis = TRUE, effect = c("twoways"), print.searchinfo = FALSE, engine = "fixest")
-
-  expect_true(identical(round(coef(aa$isatpanel.result)["temp"],7),
-                        round(coef(bb$isatpanel.result)["temp"],7)))
-})
 
 
 
